@@ -4,7 +4,7 @@ use 5.008009;
 use strict;
 use warnings;
 
-our $VERSION = 0.02;
+our $VERSION = 0.03;
 
 1;
 __END__
@@ -14,10 +14,12 @@ Bundle::Siebel::MonitoringTools - bundle for installing all Perl dependencies fo
 
 =head1 DESCRIPTION
 
-This is a bundle to install all Siebel Monitoring Tools Perl distributions that are dependencies for the project to work.
+This is a bundle to install all distributions that are required for the L<Siebel::Srvrmgr> API to work.
 
 If you don't know what it is a Perl CPAN bundle, don't worry: just installing this distribution will take care of everything else.
 
+L<Siebel::Srvrmgr> is an API to monitor Siebel On Premise CRM systems. You may find more information about in the project website.
+
 =head2 EXPORT
 
 None by default.
@@ -26,7 +28,7 @@ None by default.
 
     namespace::autoclean [0.13]
     Moose [2.0401]
-    FSA::Rules [0.32]
+    FSA::Rules [0.34]
     MooseX::Storage [0.33]
     Moose::Util::TypeConstraints [2.0402]
     MooseX::Params::Validate [0.15]
@@ -36,22 +38,25 @@ None by default.
     Log::Log4perl [1.41]
     YAML::Syck [1.27]
     Config::Tiny [2.14]
-    DBD::ODBC [1.43]
-    DBI [1.623]
     Nagios::Plugin [0.36]
     Config::Tiny [2.14]
     DBD::ODBC [1.43]
     DBI [1.623]
-    Term::Pulse [0.05]
     XML::Rabbit [0.3]
     Devel::CheckOS [1.71]
     Class::Data::Inheritable [0.08]
     Test::Class [0.36]
-    Test::Memory::Cycle [1.04]
     Test::Most [0.25]
     Test::Pod [1.22]
     Test::Pod::Coverage [1.08]
 	Test::Moose [2.0801]
+	DateTime [1.12]
+	File::BOM [0.14]
+	String::BOM [0.3]
+	Devel::Gladiator [0.07]
+	Proc::Background [1.10]
+	Proc::Daemon [0.18]
+	Proc::ProcessTable [0.51]
 
 =head1 SEE ALSO
 
@@ -59,17 +64,21 @@ None by default.
 
 =item *
 
+L<Siebel::Srvrmgr>
+
+=item *
+
 L<CPAN>
 
 =back
 
 =head1 AUTHOR
 
-Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2013 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.org<E<gt>
+This software is copyright (c) 2013 of Alceu Rodrigues de Freitas Junior, E<lt>arfreitas@cpan.orgE<gt>
 
 This file is part of Siebel Monitoring Tools.
 
